@@ -7,14 +7,10 @@ package Comics::Plugin::CalvinAndHobbes;
 
 use parent qw(Comics::Fetcher::GoComics);
 
-our $VERSION = "0.02";
+our $VERSION = "1.00";
 
-sub register {
-    shift->SUPER::register
-      ( { name    => "Calvin and Hobbes",
-	  url     => "http://www.comics.com/calvinandhobbes",
-	} );
-}
+our $name = "Calvin and Hobbes";
+our $url  = "http://www.comics.com/calvinandhobbes";
 
 # Important: Return the package name!
 __PACKAGE__;
