@@ -7,20 +7,16 @@ package Comics::Plugin::Nozzman;
 
 use parent qw(Comics::Fetcher::Single);
 
-our $VERSION = "1.00";
+our $VERSION = "1.01";
 
 our $name    = "Nozzman";
-our $url     = "http://www.nozzman.nl/cartoons/";
+our $url     = "https://nozzman.nl/persoonlijk-werk";
 
 our $pattern =
-  qr{ <noscript>
-      <img \s+
-       src="(?<url>https://images.squarespace-cdn.com/
-	     content/v1/
+  qr{ <meta \s+ property="og:image" \s+
+       content="(?<url>https://pro2-bar-s3-cdn-cf1.myportfolio.com/
 		[-_0-9a-z]+/
-		[-_0-9a-z]+/
-		[-_0-9a-z]+/
-		(?<image>[^./]+\.\w+))"
+		(?<image>[^./]+\.\w+))(?:"|\?)
     }ix;
 
 # Important: Return the package name!
